from setuptools import setup, find_packages

setup(
    name="asilbek",
    version="0.1.0",
    description="Asilbek tomonidan yaratilgan kichik Python kutubxona",
    author="Asilbek Sadullayev",
    packages=find_packages(),
    python_requires=">=3.7",
)
